//
// Start-up program
// Used to display splash screen dialog and quit
//
// Copyright (c) 1995 SoftCircuits
// Redistributed by Permission.
//


#include "windows.h"

#define ID_TIMER  1


HINSTANCE hInst;

BOOL __export CALLBACK SplashProc(HWND, UINT, WORD, LONG);
void DrawBitmap(HDC hDC, HBITMAP hBitmap);


//
// WinMain
//
int PASCAL WinMain(HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{

   if (hPrevInstance)
        return 0;
        
   hInst = hInstance;

   // Run splash screen as modal dialog
   DialogBox(hInstance, "SplashDlg", NULL, SplashProc);

   return 0;
}

//
// Splash screen dialog procedure
//
BOOL __export CALLBACK SplashProc(HWND hDlg, UINT message, WORD wParam, LONG lParam)
{
   RECT rc;
   HDC hDC, hMemDC;
   PAINTSTRUCT ps;
   HBITMAP hBitmap;
   BITMAP bm;

   switch (message) {

      case WM_INITDIALOG:
 
         // Size dialog to fit bitmap, center on screen and make it a topmost window
         hBitmap = LoadBitmap(hInst, "SplashBmp");
         GetObject(hBitmap, sizeof(BITMAP), (LPSTR)&bm);
         rc.left = (GetSystemMetrics(SM_CXFULLSCREEN) - bm.bmWidth) / 2;
         rc.top =  (GetSystemMetrics(SM_CYFULLSCREEN) - bm.bmHeight) / 2;
         SetWindowPos(hDlg, HWND_TOPMOST, rc.left, rc.top, bm.bmWidth, bm.bmHeight, 0);
         DeleteObject(hBitmap);

         // Set a timer for automatic unloading
         if (!SetTimer(hDlg, ID_TIMER, 5000, NULL))
            EndDialog(hDlg, TRUE);     // Whoops! No more timers. Abort!
         else
            ShowWindow(hDlg, SW_SHOW); // Force update
         
         return (TRUE);


      case WM_PAINT:

         // Display bitmap      
         hBitmap = LoadBitmap(hInst, "SplashBmp");
         GetObject(hBitmap, sizeof(BITMAP), (LPVOID)&bm);
         hDC = BeginPaint(hDlg, &ps);
         hMemDC = CreateCompatibleDC(hDC);
         SelectObject(hMemDC, hBitmap);
         BitBlt(hDC, 0, 0, bm.bmWidth, bm.bmHeight, hMemDC, 0, 0, SRCCOPY);
         DeleteDC(hMemDC);
         EndPaint(hDlg, &ps);
         DeleteObject(hBitmap);
         break;


      case WM_TIMER:

         // Got timer; close dialog
         EndDialog(hDlg, TRUE);
         KillTimer(hDlg, ID_TIMER);
         break;


      case WM_COMMAND:

         // Normally, the splash screen won't have any buttons but if a button
         // exists with an ID of 1001, use it to terminate the dialog
         if (wParam == 1001) {
            EndDialog(hDlg, TRUE);
            KillTimer(hDlg, ID_TIMER);
            return (TRUE);
         }
         break;
   }

   return (FALSE);      // Didn't process a message

}

